@@ -13,19 +13,23 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2005 ImageMagick Studio LLC"
-#define MagickLibVersion  0x619
-#define MagickLibVersionText  "6.1.9"
-#define MagickLibVersionNumber  6.1.9,0
+#define MagickLibVersion  0x623
+#define MagickLibVersionText  "6.2.3"
+#define MagickLibVersionNumber  6.2.3,3
 #if (QuantumDepth == 8)
 #define MagickQuantumDepth  "Q8"
+#define MagickQuantumRange  "255"
 #elif (QuantumDepth == 16)
 #define MagickQuantumDepth  "Q16"
+#define MagickQuantumRange  "65535"
 #elif (QuantumDepth == 32)
 #define MagickQuantumDepth  "Q32"
+#define MagickQuantumRange  "4294967295"
 #else
 #define MagickQuantumDepth  "Q?"
+#define MagickQuantumRange  "?"
 #endif
-#define MagickReleaseDate  "01/20/05"
+#define MagickReleaseDate  "07/13/05"
 #define MagickVersion MagickPackageName " " MagickLibVersionText " " \
   MagickReleaseDate " " MagickQuantumDepth " " MagickHomeURL
 #define MagickHomeURL  "http://www.imagemagick.org"
@@ -37,6 +41,7 @@ extern MagickExport const char
   *GetMagickCopyright(void),
   *GetMagickPackageName(void),
   *GetMagickQuantumDepth(unsigned long *),
+  *GetMagickQuantumRange(unsigned long *),
   *GetMagickReleaseDate(void),
   *GetMagickVersion(unsigned long *);
 
